# Domo Phoenix

Build Domo Phoenix Charts using Python.

## Installation

This module uses Python 3.

```shell
$ python3 -m pip install domophoenix
```

## Usage

From your Jupyter notebook, enter the following in a cell:

```python
data = [
    ['Low', 'Corporate', 8582.8875],
    ['High', 'Home Office', 14415.941],
    ['Low', 'Consumer', 1264.8215],
    ['Medium', 'Small Business', 21478.799],
    ['Critical', 'Consumer', 2621.97],
    ['Not Specified', 'Consumer', 2211.31],
    ['Critical', 'Corporate', 10087.1315],
    ['Not Specified', 'Corporate', 4407.138],
    ['High', 'Consumer', 11667.366],
    ['High', 'Corporate', 19503.323],
    ['Low', 'Small Business', 1735.3715],
    ['Low', 'Home Office', 10057.42],
    ['Medium', 'Home Office', 7691.02],
    ['Critical', 'Small Business', 4036.064],
    ['Not Specified', 'Small Business', 84.99],
    ['High', 'Small Business', 689.74],
    ['Critical', 'Home Office', 7416.828],
    ['Not Specified', 'Home Office', 1839.26],
    ['Medium', 'Consumer', 4280.034],
    ['Medium', 'Corporate', 7965.238]
]

columns = [
    {
      "type": 'STRING',
      "name": 'Order Priority',
      "mapping": 'SERIES'
    },
    {
      "type": 'STRING',
      "name": 'Customer Segment',
      "mapping": 'ITEM'
    },
    {
      "type": 'DOUBLE',
      "name": 'Sales',
      "mapping": 'VALUE'
    }
]

from domophoenix import DomoPhoenixPlotter
plotter = DomoPhoenixPlotter()
plotter.plot(data, columns, 'badge_vert_bar')
```

When you run the chart, you'll see your chart rendered!
